Package: RCircos
Type: Package
Title: Circos 2D Track Plot
Version: 1.2.2
Date: 2021-12-14
Author: Hongen Zhang 
Maintainer: Hongen Zhang <hzhang.henry@gmail.com>
Description: A simple and flexible way to generate Circos 2D track plot images for genomic data visualization is implemented in this package. The types of plots include: heatmap, histogram, lines, scatterplot, tiles and plot items for further decorations include connector, link (lines and ribbons), and text (gene) label. All functions require only R graphics package that comes with R base installation.  
License: GPL (>= 2)
Depends: R (>= 2.10)
URL: https://github.com/hzhanghenry/RCircos
NeedsCompilation: no
Packaged: 2021-12-19 17:10:42 UTC; hzhang
Repository: CRAN
Date/Publication: 2021-12-19 18:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 23:39:15 UTC; unix
