importFrom("grDevices", "col2rgb", "colors", "rgb")
importFrom("graphics", "lines", "par", "plot.new", "plot.window",
             "points", "polygon", "rect", "text")
importFrom("utils", "as.roman")

exportPattern("^[[:alpha:]]+")